CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_power.h File Reference

CCL

Functions
ccl_power.h File Reference
`#include "ccl_core.h"`

Go to the source code of this file.

## Functions
double | ccl_linear_matter_power (ccl_cosmology *cosmo, double k, double a, int *status)
double | ccl_nonlin_matter_power (ccl_cosmology *cosmo, double k, double a, int *status)
double | ccl_sigmaR (ccl_cosmology *cosmo, double R, int *status)
double | ccl_sigma8 (ccl_cosmology *cosmo, int *status)

## Function Documentation

## ◆ ccl_linear_matter_power()

double ccl_linear_matter_power | ( | ccl_cosmology * | cosmo,
|  | double | k,
|  | double | a,
|  | int * | status
| ) |  |

Linear matter power spectrum. Returns P_lin(k,a) [Mpc^3] for given cosmology, using the method specified in cosmo->config.transfer_function_method.

Parameters

  cosmo | Cosmology parameters and configurations
  k | Fourier mode, in [1/Mpc] units
  a | scale factor, normalized to 1 for today
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  P_lin(k,a).

## ◆ ccl_nonlin_matter_power()

double ccl_nonlin_matter_power | ( | ccl_cosmology * | cosmo,
|  | double | k,
|  | double | a,
|  | int * | status
| ) |  |

Non-linear matter power spectrum. Returns P_NL(k,a) [Mpc^3] for given cosmology, using the method specified in cosmo->config.transfer_function_method and cosmo->config.matter_power_spectrum_method.

Parameters

  cosmo | Cosmology parameters and configurations
  k | Fourier mode, in [1/Mpc] units
  a | scale factor, normalized to 1 for today
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  P_NL(k,a).

## ◆ ccl_sigma8()

double ccl_sigma8 | ( | ccl_cosmology * | cosmo,
|  | int * | status
| ) |  |

Computes sigma_8, variance of the matter density field with (top-hat) smoothing scale R = 8 Mpc/h, from linear power spectrum. Returns sigma_8 for specified cosmology.

Parameters

  cosmo | Cosmology parameters and configurations
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  sigma_8.

## ◆ ccl_sigmaR()

double ccl_sigmaR | ( | ccl_cosmology * | cosmo,
|  | double | R,
|  | int * | status
| ) |  |

Variance of the matter density field with (top-hat) smoothing scale R [Mpc]. Returns sigma(R) for specified cosmology at a = 1.

Parameters

  cosmo | Cosmology parameters and configurations
  R | Smoothing scale, in [Mpc] units
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  sigma(R).